@@ -17,17 +17,17 @@ __all__ = ['load', 'load_both', 'container_to_pkl']
 
 # TODO: fix Redefining built-in 'format' here
 def load(filepath='.', format='beta_value', file_stem='', verbose=False, silent=False, column_names=None, no_poobah=False, pval_cutoff=0.05, no_filter=True):
-    """When methylprep processes large datasets, you use the 'batch_size' option to keep memory and file size
-    more manageable. Use the `load` helper function to quickly load and combine all of those parts into a single
-    data frame of beta-values or m-values.
+    """Methylsuite's all-purpose data loading function.
 
-    Doing this with pandas is about 8 times slower than using numpy in the intermediate step.
+When methylprep processes large datasets, you use the 'batch_size' option to keep memory and file size
+more manageable. Use the `load` helper function to quickly load and combine all of those parts into a single
+data frame of beta-values or m-values.
 
-    If no arguments are supplied, it will load all files in current directory that have a 'beta_values_X.pkl' pattern.
+Doing this with pandas is about 8 times slower than using numpy in the intermediate step.
+
+If no arguments are supplied, it will load all files in current directory that have a 'beta_values_X.pkl' pattern.
 
 Arguments:
-==========
-
     filepath:
         Where to look for all the pickle files of processed data.
 
@@ -59,7 +59,7 @@ Arguments:
         if False, removes probes that illumina, the manufacturer, claimed are sketchy in 2019 for a select list of newer EPIC Sentrix_IDs.
         only affects 'beta_value' and 'm_value' output; no effect on meth/unmeth raw/NOOB intensity values returned.
 
-    file_stem (string):
+    file_stem: (string)
         Older versions (pre v1.3.0) of methylprep processed with batch_size created a bunch of generically named files, such as
         'beta_values_1.pkl', 'beta_values_2.pkl', 'beta_values_3.pkl', and so on. IF you rename these or provide
         a custom name during processing, provide that name here to load them all.
@@ -72,47 +72,49 @@ Arguments:
         suppresses all processing messages, even warnings.
 
 Use cases and format:
-=====================
-
-    format = beta_value
+    format = beta_value:
         you have beta_values.pkl file in the path specified and want a dataframe returned
         or you have a bunch of beta_values_1.pkl files in the path and want them merged and returned as one dataframe
         (when using 'batch_size' option in methylprep.run_pipeline() you'll get multiple files saved)
-    format = m_value
+    format = m_value:
         you have m_values.pkl file in the path specified and want a dataframe returned
         or you have a bunch of m_values_1.pkl files in the path and want them merged and returned as one dataframe
-    format = meth (data_containers)
+    format = meth: (data_containers)
         you have processed CSV files in the path specified and want a data_container returned
-    format = meth (dataframe)
+    format = meth_df: (dataframe)
         you have processed CSV files in the path specified and want a dataframe returned
         take the data_containers object returned and run `methylcheck.container_to_pkl(containers, save=True)` function on it.
-    format = sesame
+    format = sesame:
         for reading csvs processed using R's sesame package. It has a different format (Probe_ID, ind_beta, ind_negs, ind_poob) per sample.
         Only those probes that pass the p-value cutoff will be included.
+    format = beta_csv:
+        for reading processed.csv files from methylprep, and forcing it NOT to load from the pickled beta dataframe file, if present.
 
-Science on p-value cutoff:
-    This function defaults to a p-value cutoff of 0.05, which is typical for scientific tests.
-    There is currently no consensus on what percent of a sample's probes can fail. For example,
-    if a sample has 860,000 probes and 5% of them fail, should you reject the whole sample from the batch?
-    For large batch industrial scale testing, the authors assign some limit, like 5%, 10%, 20%, 30%, etc as a cutoff. And methylcheck's run_qc() function defaults to 10 percent.
-    But the academics we spoke to don't automatically throw out any samples. Because it depends.
-    Cancer samples have lots of anueploidy (an abnormal number of chromosomes in a haploid set) and lost chromosomes, so one would expect no signal for these CpG sites.
-    So those researchers wouldn't throw out samples unless most of the sample fails.
-    People are working on deriving a calibration curve from public GEO data as a guide, and give a frame of reference, but none exist yet. And public data rarely includes failed samples.
+.. note::
+   Science on p-value cutoff:
+        This function defaults to a p-value cutoff of 0.05, which is typical for scientific tests.
+        There is currently no consensus on what percent of a sample's probes can fail. For example,
+        if a sample has 860,000 probes and 5% of them fail, should you reject the whole sample from the batch?
+        For large batch industrial scale testing, the authors assign some limit, like 5%, 10%, 20%, 30%, etc as a cutoff. And methylcheck's run_qc() function defaults to 10 percent.
+        But the academics we spoke to don't automatically throw out any samples. Because it depends.
+        Cancer samples have lots of anueploidy (an abnormal number of chromosomes in a haploid set) and lost chromosomes, so one would expect no signal for these CpG sites.
+        So those researchers wouldn't throw out samples unless most of the sample fails.
+        People are working on deriving a calibration curve from public GEO data as a guide, and give a frame of reference, but none exist yet. And public data rarely includes failed samples.
 
-TODO:
+.. todo::
     - BUG: custom fields cannot auto detect the -pval- column and this isn't supplied in kwargs
     - DONE: meth_df deal with batches of files
 
-NOTES:
-    - modified this from methylprep on 2020-02-20 to allow for data_containers to be returned as option
-    - v0.6.3: added 'no_filter' step that automatically removes probes that illumina, the manufacturer, claims are sketchy for certain Catalog IDs. (Disable this with `no_filter=True`)
+.. note::
+   - modified this from methylprep on 2020-02-20 to allow for data_containers to be returned as option
+   - v0.6.3: added 'no_filter' step that automatically removes probes that illumina, the manufacturer, claims are sketchy for certain Catalog IDs. (Disable this with `no_filter=True`)
     """
     #1a: validate inputs
-    formats = ('beta_value', 'm_value', 'meth', 'meth_df', 'noob_df', 'sesame')
+    formats = ('beta_value', 'm_value', 'meth', 'meth_df', 'noob_df', 'sesame', 'beta_csv')
     if format not in formats:
         raise ValueError(f"Check the spelling of your format. Allowed: {formats}")
-    #1b: set meta flags
+
+    #1c: set meta flags
     processed_csv = False # whether to use individual sample files, or beta pkl files.
     total_parts = []
     poobah_parts = []
@@ -199,7 +201,7 @@ NOTES:
                     # you get a 30% speed up if you only load the columns you need here
                     if column_names is not None:
                         columns = column_names
-                    elif format == 'beta_value':
+                    elif format in ('beta_value','beta_csv'):
                         columns = ['IlmnID', 'beta_value']
                     elif format == 'm_value':
                         columns = ['IlmnID', 'm_value']
@@ -253,7 +255,7 @@ NOTES:
                 # FUTURE TODO: if sample_sheet or meta_data supplied, fill in with proper sample_names here
                 # incorporate .load_both() here
 
-                if 'beta_value' in sample.columns and format == 'beta_value':
+                if 'beta_value' in sample.columns and format in ('beta_value','beta_csv'):
                     if no_poobah == False and 'beta_value' in sample.columns and 'poobah_pval' in sample.columns:
                         sample.loc[sample['poobah_pval'] >= pval_cutoff, 'beta_value'] = np.nan
                     if no_filter == False and 'beta_value' in sample.columns:
@@ -280,7 +282,7 @@ NOTES:
                 elif (column_names is not None and
                     len(column_names) == 1 and
                     column_names[0] in sample.columns and
-                    format in ('beta_value', 'm_value')):
+                    format in ('beta_value', 'm_value', 'beta_csv')):
 
                     # HERE: loading beta_value or m_value from csvs using a custom column_names option
                     # BUG::: cannot auto detect the -pval- column and isn't supplied in kwargs
@@ -361,6 +363,13 @@ NOTES:
         else:
             df = pd.read_pickle(file)
 
+        #check 2: see if single file with structure: list of dfs (mouse_probes.pkl and control_probes.pkl)
+        if len(total_parts) == 1 and isinstance(df,dict) and all([isinstance(sub_df,pd.DataFrame) for sub_df in df.values()]):
+            probes_per_sample = int(sum([sub_df.shape[0] for sub_df in df.values()])/len(df.values()))
+            if verbose: LOGGER.info(f"Reading a dictionary of dataframes with {len(df)} samples and {probes_per_sample} probes.")
+            if verbose: LOGGER.info("No futher merging or poobah filtering applied to this file.")
+            return df
+
         # ensure probes are in rows.
         if df.shape[0] < df.shape[1]:
             df = df.transpose()
@@ -372,7 +381,7 @@ NOTES:
 
         if processed_csv:
             # p-value filtering already applied in earlier step when CSVs were read and collated into dataframe
-            if format == 'beta_value':
+            if format in ('beta_value','beta_csv'):
                 samples = samples.append(df['beta_value'])
             if format == 'm_value':
                 samples = samples.append(df['m_value'])
